@@ -196,9 +196,11 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
     }
 
     if (isFALSE(api_result)) {
-      usethis::ui_stop("It has not been possible to reach the API with {attempts} attempts. Consider increasing the waiting time between calls with the {usethis::ui_code('wait')} parameter or check your internet connection.")
+      cli::cli_abort(c(
+        "Could not reach the API with {attempts} attempts.",
+        i = "Consider increasing the waiting time between calls with the {.arg wait} parameter or check your internet connection."))
     } else if (length(api_result) == 1) {
-      usethis::ui_stop("Page not found. Make sure that language parameter is consistent with the language of the input title or url.")
+      cli::cli_abort("Page not found. Make sure that language parameter is consistent with the language of the input title or url.")
     } else {
       base_json <- api_result
     }
@@ -239,7 +241,10 @@ tw_get_wikipedia_category_members_single <- function(url = NULL,
       }
 
       if (isFALSE(api_result)) {
-        usethis::ui_stop("It has not been possible to reach the API with {attempts} attempts. Consider increasing the waiting time between calls with the {usethis::ui_code('wait')} parameter or check your internet connection.")
+        cli::cli_abort(c(
+          "Could not reach the API with {attempts} attempts.",
+          i = "Consider increasing the waiting time between calls with the {.arg wait} parameter or check your internet connection."
+          ))
       } else {
         base_json <- api_result
       }
@@ -539,10 +544,10 @@ tw_reset_wikipedia_category_members_cache <- function(language = tidywikidatar::
     # do nothing: if table does not exist, nothing to delete
   } else if (isFALSE(ask)) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    usethis::ui_info(paste0("Wikipedia category members cache reset for language ", sQuote(language), " completed"))
-  } else if (usethis::ui_yeah(x = paste0("Are you sure you want to remove from cache the Wikipedia category members cache for language: ", sQuote(language), "?"))) {
+    cli::cli_inform("Wikipedia category members cache reset for language {.val {language}} completed.")
+  } else if (utils::menu(c("Yes", "No"), title = paste0("Are you sure you want to remove from cache the Wikipedia category members cache for language: ", sQuote(language), "?")) == 1) {
     pool::dbRemoveTable(conn = db, name = table_name)
-    usethis::ui_info(paste0("Wikipedia category members cache reset for language ", sQuote(language), " completed"))
+    cli::cli_inform("Wikipedia category members cache reset for language {.val {language}} completed.")
   }
 
   tw_disconnect_from_cache(
